import * as path from "path";

export const frameworkConfig = {
    db: {
        cassandra: {
            contactPoints: [
                "127.0.0.1",
            ],
        },
        elasticsearch: {
            host: "127.0.0.1:9200",
            disabledApis: [
                "cat",
                "cluster",
                "ingest",
                "nodes",
                "remote",
                "snapshot",
                "tasks",
            ],
        },
        couchdb: {
            url: "http://localhost:5984",
        },
        pouchdb: {
            path: "./",
        },
    },
    plugins: [
        {
            id: "openrap-sunbirded-plugin", ver: "1.0",
        },
    ],
    pluginBasePath: path.join(__dirname, "..", "test") + "/",
    logBasePath: "./"
};

export const env = {
    APP_BASE_URL: "https://dev.sunbirded.org",
    CHANNEL: "sunbird",
    TELEMETRY_SYNC_INTERVAL_IN_SECS: "30",
    APP_ID: "local.sunbird.desktop",
    TELEMETRY_PACKET_SIZE: "200",
    APP_BASE_URL_TOKEN: "",
    APP_NAME: "SUNBIRD",
    MODE: "standalone",
    APPLICATION_PORT: "9010",
    DATABASE_PATH: "test_data/database",
    FILES_PATH: "test_data",
};

// telemetry Events mock data

export const registerDevice = {
    id: "local.sunbird.desktop",
    ver: "2.0",
    ts: "2019-07-25T12:18:44+05:30",
    params: { msgid: "a9f9c5f8-30b7-709c-9023-d9961799be2a" },
    request: {
        did: "3075dfa43b760f0ce8c21e52762d2040",
        producer: "local.sunbird.desktop",
        uaspec: {
            agent: "Chrome",
            ver: "72.0.3626.119",
            system: "mac-os-x-14",
            platform: "Mac",
            raw:
                "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/72.0.3626.119 Safari/537.36",
        },
    },
};

export const telemetry_v1 = {
    id: "ekstep.telemetry",
    ver: "3.0",
    ets: 1564039418270,
    events: [
        {
            eid: "LOG",
            ets: 1563965979045,
            ver: "3.0",
            mid: "LOG:f473ffc48fd24726703d7f94625613de",
            actor: { id: "3075dfa43b760f0ce8c21e52762d2040", type: "User" },
            context: {
                channel: "505c7c48ac6dc1edc9b08f21db5a571d",
                pdata: { id: "local.sunbird.desktop", ver: "2.0", pid: "sunbird-portal" },
                env: "app",
                sid: "7fcfd20e-2fed-8c2a-a229-88893280b219",
                did: "3075dfa43b760f0ce8c21e52762d2040",
                cdata: [],
                rollup: { l1: "505c7c48ac6dc1edc9b08f21db5a571d" },
            },
            object: {},
            tags: ["505c7c48ac6dc1edc9b08f21db5a571d"],
            edata: {
                type: "cdn_failed",
                level: "ERROR",
                message: "cdn failed, loading files from portal",
                pageid: "/",
            },
        },
        {
            eid: "IMPRESSION",
            ets: 1563965979193,
            ver: "3.0",
            mid: "IMPRESSION:a6fadae44c3c68fb3c65da6965e7f342",
            actor: { id: "3075dfa43b760f0ce8c21e52762d2040", type: "User" },
            context: {
                channel: "505c7c48ac6dc1edc9b08f21db5a571d",
                pdata: { id: "local.sunbird.desktop", ver: "2.0", pid: "sunbird-portal" },
                env: "explore",
                sid: "7fcfd20e-2fed-8c2a-a229-88893280b219",
                did: "3075dfa43b760f0ce8c21e52762d2040",
                cdata: [],
                rollup: { l1: "505c7c48ac6dc1edc9b08f21db5a571d" },
            },
            object: {},
            tags: ["505c7c48ac6dc1edc9b08f21db5a571d"],
            edata: {
                type: "view",
                pageid: "explore",
                uri: "/",
                subtype: "pageexit",
                duration: 0.247,
                visits: [
                    {
                        objid: "do_312796455240941568116824",
                        objtype: "TextBook",
                        index: 0,
                        section: "Recently Added Content",
                    },
                    {
                        objid: "do_31238451795958169622481",
                        objtype: "Resource",
                        index: 1,
                        section: "Recently Added Content",
                    },
                    {
                        objid: "do_31237103436090572825064",
                        objtype: "Resource",
                        index: 2,
                        section: "Recently Added Content",
                    },
                    {
                        objid: "do_312712227370819584110453",
                        objtype: "TextBook",
                        index: 3,
                        section: "Recently Added Content",
                    },
                    {
                        objid: "do_312352489715515392249",
                        objtype: "Collection",
                        index: 4,
                        section: "Recently Added Content",
                    },
                    {
                        objid: "do_3123527090367447042123",
                        objtype: "Collection",
                        index: 5,
                        section: "Recently Added Content",
                    },
                    {
                        objid: "do_3123526505853992961117",
                        objtype: "Collection",
                        index: 6,
                        section: "Recently Added Content",
                    },
                    { objid: "do_30080803", objtype: "Worksheet", index: 0, section: "Class 1" },
                    { objid: "do_30082101", objtype: "Worksheet", index: 1, section: "Class 1" },
                    { objid: "do_30085538", objtype: "Story", index: 2, section: "Class 1" },
                    { objid: "do_30089450", objtype: "Story", index: 3, section: "Class 1" },
                    { objid: "do_30095820", objtype: "Worksheet", index: 4, section: "Class 1" },
                    { objid: "do_30096684", objtype: "Worksheet", index: 5, section: "Class 1" },
                    { objid: "do_30100713", objtype: "Story", index: 6, section: "Class 1" },
                ],
            },
        },
        {
            eid: "INTERACT",
            ets: 1564035276476,
            ver: "3.0",
            mid: "INTERACT:e8d48999046e00b8e0a20b33c0acd0f8",
            actor: { id: "3075dfa43b760f0ce8c21e52762d2040", type: "User" },
            context: {
                channel: "505c7c48ac6dc1edc9b08f21db5a571d",
                pdata: { id: "local.sunbird.desktop", ver: "2.0", pid: "sunbird-portal" },
                env: "explore",
                sid: "7fcfd20e-2fed-8c2a-a229-88893280b219",
                did: "3075dfa43b760f0ce8c21e52762d2040",
                cdata: [],
                rollup: { l1: "505c7c48ac6dc1edc9b08f21db5a571d" },
            },
            object: {},
            tags: ["505c7c48ac6dc1edc9b08f21db5a571d"],
            edata: { id: "myLibrary-tab", type: "click", pageid: "library" },
        },
        {
            eid: "INTERACT",
            ets: 1564038598254,
            ver: "3.0",
            mid: "INTERACT:206119667439670a0698e52e83d3d244",
            actor: { id: "3075dfa43b760f0ce8c21e52762d2040", type: "User" },
            context: {
                channel: "505c7c48ac6dc1edc9b08f21db5a571d",
                pdata: { id: "local.sunbird.desktop", ver: "2.0", pid: "sunbird-portal" },
                env: "explore",
                sid: "7fcfd20e-2fed-8c2a-a229-88893280b219",
                did: "3075dfa43b760f0ce8c21e52762d2040",
                cdata: { id: "do_31238451795958169622481", type: "Resource" },
                rollup: { l1: "505c7c48ac6dc1edc9b08f21db5a571d" },
            },
            object: { id: "do_31238451795958169622481", type: "Resource", ver: "1.0", rollup: {} },
            tags: ["505c7c48ac6dc1edc9b08f21db5a571d"],
            edata: { id: "content-card", type: "click", pageid: "explore" },
        },
        {
            eid: "IMPRESSION",
            ets: 1564038598591,
            ver: "3.0",
            mid: "IMPRESSION:ad6174e2ef0b08ec52b1351a5e826ddf",
            actor: { id: "3075dfa43b760f0ce8c21e52762d2040", type: "User" },
            context: {
                channel: "505c7c48ac6dc1edc9b08f21db5a571d",
                pdata: { id: "local.sunbird.desktop", ver: "2.0", pid: "sunbird-portal" },
                env: "explore",
                sid: "7fcfd20e-2fed-8c2a-a229-88893280b219",
                did: "3075dfa43b760f0ce8c21e52762d2040",
                cdata: [],
                rollup: { l1: "505c7c48ac6dc1edc9b08f21db5a571d" },
            },
            object: {},
            tags: ["505c7c48ac6dc1edc9b08f21db5a571d"],
            edata: {
                type: "view",
                pageid: "explore",
                uri: "/",
                subtype: "pageexit",
                duration: 0.247,
                visits: [
                    {
                        objid: "do_312796455240941568116824",
                        objtype: "TextBook",
                        index: 0,
                        section: "Recently Added Content",
                    },
                    {
                        objid: "do_31238451795958169622481",
                        objtype: "Resource",
                        index: 1,
                        section: "Recently Added Content",
                    },
                    {
                        objid: "do_31237103436090572825064",
                        objtype: "Resource",
                        index: 2,
                        section: "Recently Added Content",
                    },
                    {
                        objid: "do_312712227370819584110453",
                        objtype: "TextBook",
                        index: 3,
                        section: "Recently Added Content",
                    },
                    {
                        objid: "do_312352489715515392249",
                        objtype: "Collection",
                        index: 4,
                        section: "Recently Added Content",
                    },
                    {
                        objid: "do_3123527090367447042123",
                        objtype: "Collection",
                        index: 5,
                        section: "Recently Added Content",
                    },
                    {
                        objid: "do_3123526505853992961117",
                        objtype: "Collection",
                        index: 6,
                        section: "Recently Added Content",
                    },
                    { objid: "do_30080803", objtype: "Worksheet", index: 0, section: "Class 1" },
                    { objid: "do_30082101", objtype: "Worksheet", index: 1, section: "Class 1" },
                    { objid: "do_30085538", objtype: "Story", index: 2, section: "Class 1" },
                    { objid: "do_30089450", objtype: "Story", index: 3, section: "Class 1" },
                    { objid: "do_30095820", objtype: "Worksheet", index: 4, section: "Class 1" },
                    { objid: "do_30096684", objtype: "Worksheet", index: 5, section: "Class 1" },
                    { objid: "do_30100713", objtype: "Story", index: 6, section: "Class 1" },
                ],
            },
        },
        {
            eid: "IMPRESSION",
            ets: 1564038598636,
            ver: "3.0",
            mid: "IMPRESSION:2e118ff7720c00d894c8b712a444b3e9",
            actor: { id: "3075dfa43b760f0ce8c21e52762d2040", type: "User" },
            context: {
                channel: "505c7c48ac6dc1edc9b08f21db5a571d",
                pdata: { id: "local.sunbird.desktop", ver: "2.0", pid: "sunbird-portal" },
                env: "public",
                sid: "7fcfd20e-2fed-8c2a-a229-88893280b219",
                did: "3075dfa43b760f0ce8c21e52762d2040",
                cdata: [],
                rollup: { l1: "505c7c48ac6dc1edc9b08f21db5a571d" },
            },
            object: { id: "do_31238451795958169622481", type: "Resource", ver: "1.0", rollup: {} },
            tags: ["505c7c48ac6dc1edc9b08f21db5a571d"],
            edata: {
                type: "view",
                pageid: "play-content",
                uri: "/play/content/do_31238451795958169622481?contentType=Resource",
                subtype: "paginate",
                duration: 0.374,
            },
        },
        {
            eid: "INTERACT",
            ets: 1564039059097,
            ver: "3.0",
            mid: "INTERACT:8f1e07308500e54ab0c69f55c3c7029b",
            actor: { id: "3075dfa43b760f0ce8c21e52762d2040", type: "User" },
            context: {
                channel: "505c7c48ac6dc1edc9b08f21db5a571d",
                pdata: { id: "local.sunbird.desktop", ver: "2.0", pid: "sunbird-portal" },
                env: "public",
                sid: "7fcfd20e-2fed-8c2a-a229-88893280b219",
                did: "3075dfa43b760f0ce8c21e52762d2040",
                cdata: [],
                rollup: { l1: "505c7c48ac6dc1edc9b08f21db5a571d" },
            },
            object: { id: "do_31238451795958169622481", type: "Resource", ver: "1.0", rollup: {} },
            tags: ["505c7c48ac6dc1edc9b08f21db5a571d"],
            edata: { id: "close-player", type: "click", pageid: "public" },
        },
        {
            eid: "IMPRESSION",
            ets: 1564039059316,
            ver: "3.0",
            mid: "IMPRESSION:e4dbba04f2b33f86c69307e1595b3e45",
            actor: { id: "3075dfa43b760f0ce8c21e52762d2040", type: "User" },
            context: {
                channel: "505c7c48ac6dc1edc9b08f21db5a571d",
                pdata: { id: "local.sunbird.desktop", ver: "2.0", pid: "sunbird-portal" },
                env: "explore",
                sid: "7fcfd20e-2fed-8c2a-a229-88893280b219",
                did: "3075dfa43b760f0ce8c21e52762d2040",
                cdata: [],
                rollup: { l1: "505c7c48ac6dc1edc9b08f21db5a571d" },
            },
            object: {},
            tags: ["505c7c48ac6dc1edc9b08f21db5a571d"],
            edata: {
                type: "view",
                pageid: "explore",
                uri: "/",
                subtype: "pageexit",
                duration: 0.108,
                visits: [
                    {
                        objid: "do_31257981695847628819655",
                        objtype: "Resource",
                        index: 0,
                        section: "Recently Added Content",
                    },
                    {
                        objid: "do_31269800069335449615808",
                        objtype: "Resource",
                        index: 1,
                        section: "Recently Added Content",
                    },
                    {
                        objid: "do_312796455240941568116824",
                        objtype: "TextBook",
                        index: 2,
                        section: "Recently Added Content",
                    },
                    {
                        objid: "do_31238451795958169622481",
                        objtype: "Resource",
                        index: 3,
                        section: "Recently Added Content",
                    },
                    {
                        objid: "do_31237103436090572825064",
                        objtype: "Resource",
                        index: 4,
                        section: "Recently Added Content",
                    },
                    {
                        objid: "do_312712227370819584110453",
                        objtype: "TextBook",
                        index: 5,
                        section: "Recently Added Content",
                    },
                    {
                        objid: "do_312352489715515392249",
                        objtype: "Collection",
                        index: 6,
                        section: "Recently Added Content",
                    },
                    { objid: "do_30080803", objtype: "Worksheet", index: 0, section: "Class 1" },
                    { objid: "do_30082101", objtype: "Worksheet", index: 1, section: "Class 1" },
                    { objid: "do_30085538", objtype: "Story", index: 2, section: "Class 1" },
                    { objid: "do_30089450", objtype: "Story", index: 3, section: "Class 1" },
                    { objid: "do_30095820", objtype: "Worksheet", index: 4, section: "Class 1" },
                    { objid: "do_30096684", objtype: "Worksheet", index: 5, section: "Class 1" },
                    { objid: "do_30100713", objtype: "Story", index: 6, section: "Class 1" },
                ],
            },
        },
        {
            eid: "INTERACT",
            ets: 1564039417846,
            ver: "3.0",
            mid: "INTERACT:f851e674ab2653b14cd10741cdde69f9",
            actor: { id: "3075dfa43b760f0ce8c21e52762d2040", type: "User" },
            context: {
                channel: "505c7c48ac6dc1edc9b08f21db5a571d",
                pdata: { id: "local.sunbird.desktop", ver: "2.0", pid: "sunbird-portal" },
                env: "explore",
                sid: "7fcfd20e-2fed-8c2a-a229-88893280b219",
                did: "3075dfa43b760f0ce8c21e52762d2040",
                cdata: { id: "do_312796455240941568116824", type: "TextBook" },
                rollup: { l1: "505c7c48ac6dc1edc9b08f21db5a571d" },
            },
            object: { id: "do_312796455240941568116824", type: "TextBook", ver: "1.0", rollup: {} },
            tags: ["505c7c48ac6dc1edc9b08f21db5a571d"],
            edata: { id: "content-card", type: "click", pageid: "explore" },
        },
        {
            eid: "IMPRESSION",
            ets: 1564039417936,
            ver: "3.0",
            mid: "IMPRESSION:dde2f9948e9fa1b8b9ce5560b12401f3",
            actor: { id: "3075dfa43b760f0ce8c21e52762d2040", type: "User" },
            context: {
                channel: "505c7c48ac6dc1edc9b08f21db5a571d",
                pdata: { id: "local.sunbird.desktop", ver: "2.0", pid: "sunbird-portal" },
                env: "explore",
                sid: "7fcfd20e-2fed-8c2a-a229-88893280b219",
                did: "3075dfa43b760f0ce8c21e52762d2040",
                cdata: [],
                rollup: { l1: "505c7c48ac6dc1edc9b08f21db5a571d" },
            },
            object: {},
            tags: ["505c7c48ac6dc1edc9b08f21db5a571d"],
            edata: {
                type: "view",
                pageid: "explore",
                uri: "/",
                subtype: "pageexit",
                duration: 0.108,
                visits: [
                    {
                        objid: "do_31257981695847628819655",
                        objtype: "Resource",
                        index: 0,
                        section: "Recently Added Content",
                    },
                    {
                        objid: "do_31269800069335449615808",
                        objtype: "Resource",
                        index: 1,
                        section: "Recently Added Content",
                    },
                    {
                        objid: "do_312796455240941568116824",
                        objtype: "TextBook",
                        index: 2,
                        section: "Recently Added Content",
                    },
                    {
                        objid: "do_31238451795958169622481",
                        objtype: "Resource",
                        index: 3,
                        section: "Recently Added Content",
                    },
                    {
                        objid: "do_31237103436090572825064",
                        objtype: "Resource",
                        index: 4,
                        section: "Recently Added Content",
                    },
                    {
                        objid: "do_312712227370819584110453",
                        objtype: "TextBook",
                        index: 5,
                        section: "Recently Added Content",
                    },
                    {
                        objid: "do_312352489715515392249",
                        objtype: "Collection",
                        index: 6,
                        section: "Recently Added Content",
                    },
                    { objid: "do_30080803", objtype: "Worksheet", index: 0, section: "Class 1" },
                    { objid: "do_30082101", objtype: "Worksheet", index: 1, section: "Class 1" },
                    { objid: "do_30085538", objtype: "Story", index: 2, section: "Class 1" },
                    { objid: "do_30089450", objtype: "Story", index: 3, section: "Class 1" },
                    { objid: "do_30095820", objtype: "Worksheet", index: 4, section: "Class 1" },
                    { objid: "do_30096684", objtype: "Worksheet", index: 5, section: "Class 1" },
                    { objid: "do_30100713", objtype: "Story", index: 6, section: "Class 1" },
                ],
            },
        },
    ],
};
export const error_telemetry_v1 = {
    id: "ekstep.telemetry",
    ver: "3.0",
    ets: 1564039418270,
    // events: [],
};

export const telemetry_v3 = {
    id: "ekstep.telemetry",
    ver: "3.0",
    ets: 1564039636102,
    events: [
        {
            eid: "START",
            ets: 1564039597833,
            ver: "3.0",
            mid: "START:57468d165448fd5b200ae3396c4b40bf",
            actor: { id: "3075dfa43b760f0ce8c21e52762d2040", type: "User" },
            context: {
                channel: "505c7c48ac6dc1edc9b08f21db5a571d",
                pdata: { id: "local.sunbird.desktop", ver: "2.0", pid: "sunbird-portal.contentplayer" },
                env: "contentplayer",
                sid: "7fcfd20e-2fed-8c2a-a229-88893280b219",
                did: "3075dfa43b760f0ce8c21e52762d2040",
                cdata: [{ id: "2a8d213873725802e1887c39f2424c38", type: "ContentSession" }],
                rollup: { l1: "505c7c48ac6dc1edc9b08f21db5a571d" },
            },
            object: { id: "do_31251547849352806416664", type: "Content", ver: "4", rollup: {} },
            tags: [],
            edata: { type: "content", mode: "play", pageid: "", duration: 3.46 },
        },
        {
            eid: "INTERRUPT",
            ets: 1564039635765,
            ver: "3.0",
            mid: "INTERRUPT:517a9b03dd5fd605d4c7004cb3febef9",
            actor: { id: "3075dfa43b760f0ce8c21e52762d2040", type: "User" },
            context: {
                channel: "505c7c48ac6dc1edc9b08f21db5a571d",
                pdata: { id: "local.sunbird.desktop", ver: "2.0", pid: "sunbird-portal.contentplayer" },
                env: "contentplayer",
                sid: "7fcfd20e-2fed-8c2a-a229-88893280b219",
                did: "3075dfa43b760f0ce8c21e52762d2040",
                cdata: [{ id: "2a8d213873725802e1887c39f2424c38", type: "ContentSession" }],
                rollup: { l1: "505c7c48ac6dc1edc9b08f21db5a571d" },
            },
            object: { id: "do_31251547849352806416664", type: "Content", ver: "4", rollup: {} },
            tags: [],
            edata: { type: "OTHER", pageid: "" },
        },
        {
            eid: "END",
            ets: 1564039635770,
            ver: "3.0",
            mid: "END:d373c12b3bc0a1127f61f33c05ecc4a4",
            actor: { id: "3075dfa43b760f0ce8c21e52762d2040", type: "User" },
            context: {
                channel: "505c7c48ac6dc1edc9b08f21db5a571d",
                pdata: { id: "local.sunbird.desktop", ver: "2.0", pid: "sunbird-portal.contentplayer" },
                env: "contentplayer",
                sid: "7fcfd20e-2fed-8c2a-a229-88893280b219",
                did: "3075dfa43b760f0ce8c21e52762d2040",
                cdata: [{ id: "2a8d213873725802e1887c39f2424c38", type: "ContentSession" }],
                rollup: { l1: "505c7c48ac6dc1edc9b08f21db5a571d" },
            },
            object: { id: "do_31251547849352806416664", type: "Content", ver: "4", rollup: {} },
            tags: [],
            edata: {
                type: "content",
                mode: "play",
                pageid: "sunbird-player-Endpage",
                summary: [{ progress: 50 }],
                duration: 38.268,
            },
        },
    ],
};

export const error_telemetry_v3 = {
    id: "ekstep.telemetry",
    ver: "3.0",
    ets: 1564039636102,
    events: [],
};
